@@ -51,7 +51,7 @@ CONFIGURATION_FILE_PATH = get_existent_path(
 )
 
 DEFAULT_CONFIG = {
-    "default_provider": "animixplay",
+    "default_provider": "allanime",
     "site_urls": {
         "9anime": "https://9anime.pl/",
         "allanime": "https://allanime.site/",
@@ -122,6 +122,11 @@ DEFAULT_CONFIG = {
     "check_for_updates": True,
     "force_streaming_quality_selection": True,
     "aniskip": False,
+    "superanime": {
+        "return_all": False,
+        "type_of": "sub",
+        "crunchyroll": {"subtitles": "en-US"},
+    },
 }
 
 CONFIG = DEFAULT_CONFIG
@@ -186,3 +191,9 @@ FORCE_STREAMING_QUALITY_SELECTION = CONFIG.get(
 )
 
 USE_ANISKIP = CONFIG.get("aniskip", False)
+
+SUPERANIME = CONFIG.get("superanime", {})
+
+SUPERANIME_RETURN_ALL = SUPERANIME.get("return_all", False)
+SUPERANIME_TYPE_OF = SUPERANIME.get("type_of", "sub")
+SUPERANIME_CRUNCHYROLL = SUPERANIME.get("crunchyroll", {"subtitles": "en-US"})
